@@ -69,10 +69,11 @@ def fn_extract_data(result_set, ret_type: DBTypes, cursor, model, jsonfy=False)
 class ZPostgres(ZDatabase):
 
     def __init__(self, dict_config: Optional[dict] = None, config: Optional[ZDBConfig] = None,
-                 verbose: bool = False):
+                 verbose: bool = False, auto_commit: bool = True):
         self.dict_config = dict_config
         self.config = config
         self.verbose = verbose
+        self.auto_commit: bool = auto_commit
 
     @classmethod
     def setup(cls, config: dict, verbose: bool = False):
@@ -109,7 +110,9 @@ class ZPostgres(ZDatabase):
         final_config = self.__validate_config()
         if final_config is None:
             raise ValueError("The value of db configuration can not be null.")
-        return connect(**final_config)
+        connection = connect(**final_config)
+        connection.autocommit = self.auto_commit
+        return connection
 
     def exec(self, name: str, ret_type: Optional[DBTypes] = None, params: Optional[dict] = None,
              list_params: Optional[List[Any]] = None,
